;;; $DOOMDIR/config.el -*- lexical-binding: t; -*-

;; Place your private configuration here! Remember, you do not need to run 'doom
;; sync' after modifying this file!


;; Some functionality uses this to identify you, e.g. GPG configuration, email
;; clients, file templates and snippets. It is optional.
(setq user-full-name "Michael Ochmann"
      user-mail-address "miko@mike-ochmann.de")

;; Doom exposes five (optional) variables for controlling fonts in Doom:
;;
;; - `doom-font' -- the primary font to use
;; - `doom-variable-pitch-font' -- a non-monospace font (where applicable)
;; - `doom-big-font' -- used for `doom-big-font-mode'; use this for
;;   presentations or streaming.
;; - `doom-unicode-font' -- for unicode glyphs
;; - `doom-serif-font' -- for the `fixed-pitch-serif' face
;;
;; See 'C-h v doom-font' for documentation and more examples of what they
;; accept. For example:
;;
(setq doom-font (font-spec :family "Iosevka" :size 16 :weight 'semi-light)
	doom-variable-pitch-font (font-spec :family "Iosevka" :size 13)
	doom-big-font (font-spec :family "Iosevka" :size 24))

(custom-set-faces!
  '(font-lock-comment-face :regular normal)
  '(font-lock-keyword-face :regular normal))
;;
;; If you or Emacs can't find your font, use 'M-x describe-font' to look them
;; up, `M-x eval-region' to execute elisp code, and 'M-x doom/reload-font' to
;; refresh your font settings. If Emacs still can't find your font, it likely
;; wasn't installed correctly. Font issues are rarely Doom issues!

;; There are two ways to load a theme. Both assume the theme is installed and
;; available. You can either set `doom-theme' or manually load a theme with the
;; `load-theme' function. This is the default:
(setq doom-theme 'doom-monokai-classic)

;; This determines the style of line numbers in effect. If set to `nil', line
;; numbers are disabled. For relative line numbers, set this to `relative'.
(setq display-line-numbers-type t)

;; If you use `org' and don't want your org files in the default location below,
;; change `org-directory'. It must be set before org loads!
(setq org-directory "~/org/")

(add-hook 'org-mode-hook 'org-indent-mode)
(setq org-directory "~/org/"
      org-agenda-files '("~/org/agenda/*.org")
      org-default-notes-file (expand-file-name "notes.org" org-directory)
      org-ellipsis " ▼ "
      org-log-done 'time
      org-journal-dir "~/org/journal/"
      org-journal-date-format "%B %d, %Y (%A) "
      org-journal-file-format "%Y-%m-%d.org"
      org-hide-emphasis-markers t)
(setq org-src-preserve-indentation nil
      org-src-tab-acts-natively t
      org-edit-src-content-indentation 0)
(add-hook 'org-mode-hook (lambda () (org-superstar-mode 1)))


(use-package org-tempo
  :ensure nil) ;; tell use-package not to try to install org-tempo since it's already there.
(setq org-src-fontify-natively t
    org-src-tab-acts-natively t
    org-confirm-babel-evaluate nil
    org-edit-src-content-indentation 0)
(use-package toc-org
  :commands toc-org-enable
  :init (add-hook 'org-mode-hook 'toc-org-enable))


;; Whenever you reconfigure a package, make sure to wrap your config in an
;; `after!' block, otherwise Doom's defaults may override your settings. E.g.
;;
;;   (after! PACKAGE
;;     (setq x y))
;;
;; The exceptions to this rule:
;;
;;   - Setting file/directory variables (like `org-directory')
;;   - Setting variables which explicitly tell you to set them before their
;;     package is loaded (see 'C-h v VARIABLE' to look up their documentation).
;;   - Setting doom variables (which start with 'doom-' or '+').
;;
;; Here are some additional functions/macros that will help you configure Doom.
;;
;; - `load!' for loading external *.el files relative to this one
;; - `use-package!' for configuring packages
;; - `after!' for running code after a package has loaded
;; - `add-load-path!' for adding directories to the `load-path', relative to
;;   this file. Emacs searches the `load-path' when you load packages with
;;   `require' or `use-package'.
;; - `map!' for binding new keys
;;
;; To get information about any of these functions/macros, move the cursor over
;; the highlighted symbol at press 'K' (non-evil users must press 'C-c c k').
;; This will open documentation for it, including demos of how they are used.
;; Alternatively, use `C-h o' to look up a symbol (functions, variables, faces,
;; etc).
;;
;; You can also try 'gd' (or 'C-c c d') to jump to their definition and see how
;; they are implemented.

(setq display-line-numbers-type 'relative)
(setq projectile-project-search-path '("~/Documents/apps/" "~/Documents/apps/fsi/laniv" "~/Sites" "~/Documents/maschinendeck/"))
(setq projectile-enable-caching nil)

; Tabs
; https://dougie.io/emacs/indentation/#functions-for-enablingdisabling-tabs
;(setq-default indent-tabs-mode t)
(setq-default tab-width 4)
(setq custom-tab-width 4)

(defun disable-tabs () (setq indent-tabs-mode nil))
(defun enable-tabs  ()
  (local-set-key (kbd "TAB") 'tab-to-tab-stop)
  (setq indent-tabs-mode t)
  (setq tab-width custom-tab-width))
;;
;; Hooks to Enable Tabs
(add-hook 'prog-mode-hook 'enable-tabs)
(add-hook 'rjsx-mode-hook 'enable-tabs)

;; zoom in/out like we do everywhere else.
(global-set-key (kbd "C-+") 'doom/increase-font-size)
(global-set-key (kbd "C--") 'doom/decrease-font-size)
(global-set-key (kbd "<C-wheel-up>") 'text-scale-increase)
(global-set-key (kbd "<C-wheel-down>") 'text-scale-decrease)
(global-set-key (kbd "<C-tab>") 'centaur-tabs-forward)

(map! :leader
      (:prefix-map ("d" . "dired")
        (
         :desc "Open dired" "d" #'dired
         :desc "Show dired help" "s" #'dired-summary
         :desc "Toggle neotree" "n" #'neotree-toggle
	 (:after dired
		(:map dired-mode-map
			:desc "Peak into file" "p" #'peep-dired
		)
	 )
         )
       )
)
(evil-define-key 'normal peep-dired-mode-map
	(kbd "<down>") 'peep-dired-next-file
	(kbd "<up>") 'peep-dired-prev-file
)
(add-hook 'peep-dired-hook 'evil-normalize-keymaps)


(map! :leader
      (:prefix-map ("l" . "Alignment")
        (
         :desc "Align on RegEx" "r" #'align-regexp
         )
       )
)

(setq centaur-tabs-cycle-scope 'tabs)

(setq flycheck-gcc-language-standard "c++20")
