"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
"                                                                             "
"   ● ○ ○ ○ ●                                                                 "
"   ● ● ○ ● ●   Mike Ochmann                                                  "
"   ● ○ ● ○ ●   https://mike-ochmann.de                                       "
"   ● ○ ○ ○ ●                                                                 "
"   ● ○ ○ ○ ●                                                                 "
"                                                                             "
"   My configuration for the `vim` editor                                     "
"   Version 1,1,0                                                             "
"                                                                             "
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

set nocompatible
filetype off

set rtp+=$HOME/.vim/bundle/Vundle.vim
autocmd FileType php set omnifunc=phpcomplete#CompletePHP
call vundle#begin()

Plugin 'VundleVim/Vundle.vim'
Plugin 'tpope/vim-fugitive'
Plugin 'preservim/nerdtree'
Plugin 'kalafut/vim-taskjuggler'
Plugin 'octol/vim-cpp-enhanced-highlight'
Plugin 'mkusher/padawan.vim'
Plugin 'alvan/vim-closetag'
Plugin 'pangloss/vim-javascript'
Plugin 'mxw/vim-jsx'
Plugin 'junegunn/goyo.vim'
Plugin 'junegunn/limelight.vim'
Plugin 'godlygeek/tabular'
Plugin 'plasticboy/vim-markdown'
Plugin 'mg979/vim-visual-multi'
Plugin 'itchyny/calendar.vim'
Plugin 'liuchengxu/vim-which-key'
Plugin 'junegunn/vim-easy-align'

call vundle#end()            " required
filetype plugin indent on    " required

set relativenumber
set number
set nowrap
set colorcolumn=80

execute pathogen#infect()
syntax on
filetype plugin indent on
hi Normal guibg=NONE ctermbg=NONE

colorscheme monokai
let g:vim_markdown_folding_disabled = 1

" STATUSLINE
set laststatus=2

set statusline=
set statusline+=%#SpellLocal#
set statusline+=\ %{FugitiveHead()}\  
set statusline+=%#String#
set statusline+=\ \  
set statusline+=%{getcwd()}/%f
set statusline+=%m
set statusline+=%=
set statusline+=%#Folded#
set statusline+=\ [%{&fileencoding?&fileencoding:&encoding}]
set statusline+=\ %p%%
set statusline+=%#Character#
set statusline+=\ [%l:%c]

" SETUP
set tabstop=4
set shiftwidth=4
set ruler
set signcolumn=yes
set noexpandtab
set notimeout
set backspace=indent,eol,start

let g:closetag_filenames = '*.html,*.xhtml,*.phtml,*.php'
let g:python_recommended_style = 0
autocmd BufRead ~/.ssh/config.d/* set syntax=sshconfig
autocmd! User GoyoEnter Limelight
autocmd! User GoyoLeave Limelight!

" Keymaps are in `~/.vim/after/plugin/keymaps.vim`

" read bashrc for executing commands inside vim
:set shellcmdflag=-ic
